==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/da.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive til mappen \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen",
    "See %s" : "Se %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen. Se %s",
    "Sample configuration detected" : "Eksempel for konfiguration registreret",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Der er registreret at eksempel for konfiguration er blevet kopieret. Dette kan ødelægge din installation og understøttes ikke. Læs venligst dokumentationen før der foretages ændringer i config.php",
    "%1$s and %2$s" : "%1$s og %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
    "PHP %s or higher is required." : "Der kræves PHP %s eller nyere.",
    "PHP with a version lower than %s is required." : "Der kræves PHP %s eller ældre.",
    "Following databases are supported: %s" : "Følgende databaser understøttes: %s",
    "The command line tool %s could not be found" : "Kommandolinjeværktøjet %s blev ikke fundet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgængeligt.",
    "Following platforms are supported: %s" : "Følgende platforme understøttes: %s",
    "Server version %s or higher is required." : "Du skal have server version %s eller nyere.",
    "Server version %s or lower is required." : "Du skal have server version %s eller ældre.",
    "Unknown filetype" : "Ukendt filtype",
    "Invalid image" : "Ugyldigt billede",
    "today" : "i dag",
    "tomorrow" : "i morgen",
    "yesterday" : "i går",
    "_in %n day_::_in %n days_" : ["om %n dag","om %n dage"],
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dage siden"],
    "next month" : "næste måned",
    "last month" : "sidste måned",
    "_in %n month_::_in %n months_" : ["om %n måned","om %n måneder"],
    "_%n month ago_::_%n months ago_" : ["%n måned siden","%n måneder siden"],
    "next year" : "næste år",
    "last year" : "sidste år",
    "_in %n year_::_in %n years_" : ["om %n år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_in %n hour_::_in %n hours_" : ["om %n time","om %n timer"],
    "_%n hour ago_::_%n hours ago_" : ["%n time siden","%n timer siden"],
    "_in %n minute_::_in %n minutes_" : ["om %n minut","om %n minutter"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut siden","%n minutter siden"],
    "in a few seconds" : "om få sekunder",
    "seconds ago" : "sekunder siden",
    "File name is a reserved word" : "Filnavnet er et reserveret ord",
    "File name contains at least one invalid character" : "Filnavnet indeholder mindst ét ugyldigt tegn",
    "File name is too long" : "Filnavnet er for langt",
    "Dot files are not allowed" : "Filer med punktummer er ikke tilladt",
    "Empty filename is not allowed" : "Tomme filnavne er ikke tilladt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres fordi appinfo filen ikke kan læses.",
    "__language_name__" : "Dansk",
    "Help" : "Hjælp",
    "Apps" : "Apps",
    "Settings" : "Indstillinger",
    "Log out" : "Log ud",
    "Users" : "Brugere",
    "Unknown user" : "Ukendt bruger",
    "Overview" : "Overblik",
    "Basic settings" : "Grundlæggende Indstillinger",
    "Sharing" : "Deling",
    "Security" : "Sikkerhed",
    "Additional settings" : "Yderligere indstillinger",
    "Personal info" : "Personlige oplysninger",
    "Mobile & desktop" : "Mobil & desktop",
    "%s enter the database username and name." : "%s indtast brugernavn og navn til databasen.",
    "%s enter the database username." : "%s indtast database brugernavnet.",
    "%s enter the database name." : "%s indtast database navnet.",
    "%s you may not use dots in the database name" : "%s du må ikke bruge punktummer i databasenavnet.",
    "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
    "Oracle username and/or password not valid" : "Oracle brugernavn og/eller kodeord er ikke gyldigt.",
    "PostgreSQL username and/or password not valid" : "PostgreSQL brugernavn og/eller kodeord er ikke gyldigt.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X understøttes ikke og %s vil ikke virke optimalt på denne platform. Anvend på eget ansvar!",
    "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
    "Set an admin username." : "Angiv et admin brugernavn.",
    "Set an admin password." : "Angiv et admin kodeord.",
    "Can't create or write into the data directory %s" : "Kan ikke oprette eller skrive ind i datamappen %s",
    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delingsbackend'en %s skal implementere grænsefladen OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delingsbackend'en %s blev ikke fundet",
    "Sharing backend for %s not found" : "Delingsbackend'en for %s blev ikke fundet",
    "Open »%s«" : "Åbn »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Du har ikke tilladelse til at dele %s",
    "Expiration date is in the past" : "Udløbsdatoen ligger tilbage i tid",
    "Could not find category \"%s\"" : "Kunne ikke finde kategorien \"%s\"",
    "Sunday" : "Søndag",
    "Monday" : "andag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : ".",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Marts",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "eb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kun følgende tegn kan indgå i et brugernavn: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
    "Username contains whitespace at the beginning or at the end" : "Brugernavnet har et mellemrum i starten eller slutningen",
    "A valid password must be provided" : "En gyldig adgangskode skal angives",
    "The username is already being used" : "Brugernavnet er allerede i brug",
    "User disabled" : "Bruger deaktiveret",
    "Login canceled by app" : "Login annulleret af app",
    "a safe home for all your data" : "et sikkert hjem til alle dine data",
    "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
    "Can't read file" : "Kan ikke læse filen",
    "Application is not enabled" : "Programmet er ikke aktiveret",
    "Authentication error" : "Adgangsfejl",
    "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen database driver (sqlite, mysql eller postgresql) er installeret.",
    "Cannot write into \"config\" directory" : "Kan ikke skrive til mappen \"config\"",
    "Cannot write into \"apps\" directory" : "Kan ikke skrive til mappen \"apps\"",
    "Setting locale to %s failed" : "Angivelse af %s for lokalitet mislykkedes",
    "Please install one of these locales on your system and restart your webserver." : "Installér venligst én af disse lokaliteter på dit system, og genstart din webserver.",
    "Please ask your server administrator to install the module." : "Du bedes anmode din serveradministrator om at installere modulet.",
    "PHP module %s not installed." : "PHP-modulet %s er ikke installeret.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-indstillingen \"%s\" er ikke angivet til \"%s\".",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload er angivet til \"%s\", i stedet for den forventede værdi \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "For at rette dette problem, angiv\n<code>mbstring.func_overload</code> til <code>0</code> i din php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 skal mindst være version 2.7.0. Du har version %s installeret.",
    "To fix this issue update your libxml2 version and restart your web server." : "Opdater din libxml2 version og genstart webserveren for at løse problemet.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP er tilsyneladende sat op til at fjerne indlejrede doc-blokke. Dette vil gøre adskillige kerneprogrammer utilgængelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette er sansynligvis forårsaget af et accelerator eller cache som Zend OPcache eller eAccelerator",
    "PHP modules have been installed, but they are still listed as missing?" : "Der er installeret PHP-moduler, men de fremstår stadig som fraværende?",
    "Please ask your server administrator to restart the web server." : "Du bedes anmode din serveradministrator om at genstarte webserveren.",
    "Please upgrade your database version" : "Opgradér venligst din databaseversion",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Tilpas venligst rettigheder til 0770, så mappen ikke fremvises for andre brugere.",
    "Check the value of \"datadirectory\" in your configuration" : "Tjek værdien for \"databibliotek\" i din konfiguration",
    "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\".",
    "Library %s with a version higher than %s is required - available version %s." : "Der kræves en version af biblioteket %s, der er højere end %s - tilgængelig version er %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Der kræves en version af biblioteket %s, der er lavere end %s - tilgængelig version er %s.",
    "Create" : "Opret",
    "Delete" : "Slet",
    "Share" : "Del",
    "Unlimited" : "Ubegrænset",
    "Verifying" : "Bekræfter",
    "Verifying …" : "Bekræfter…",
    "Verify" : "Bekræft",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling af %s mislykkedes, fordi backenden ikke tillader delinger fra typen %i",
    "Sharing %s failed, because the file does not exist" : "Deling af %s mislykkedes, fordi filen ikke eksisterer",
    "Sharing %s failed, because you can not share with yourself" : "Deling af %s mislykkedes, fordi du ikke kan dele med dig selv",
    "Sharing %s failed, because the user %s does not exist" : "Der skete en fejl ved deling af %s, brugeren %s eksistere ikke",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Der skete en fejl ved deling af %s, brugeren %s er ikke medlem af nogle grupper som %s er medlem af",
    "Sharing %s failed, because this item is already shared with %s" : "Der skete en fejl ved deling af %s, objektet er allerede delt med %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Deling af %s mislykkedes, fordi dette element allerede er delt med brugeren %s",
    "Sharing %s failed, because the group %s does not exist" : "Der skete en fejl ved deling af %s, gruppen %s eksistere ikke",
    "Sharing %s failed, because %s is not a member of the group %s" : "Der skete en fejl ved deling af %s, fordi %s ikke er medlem af gruppen %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Du skal angive et kodeord for at oprette et offentligt link - kun beskyttede links er tilladt",
    "Sharing %s failed, because sharing with links is not allowed" : "Der skete en fejl ved deling af %s, det er ikke tilladt at dele links",
    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling af %s mislykkedes - kunne ikke finde %s. Måske er serveren ikke tilgængelig i øjeblikket.",
    "Share type %s is not valid for %s" : "Delingstypen %s er ikke gyldig for %s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan ikke angive udløbsdato. Delinger kan ikke udløbe senere end %s efter at de er blevet delt",
    "Cannot set expiration date. Expiration date is in the past" : "Kan ikke angive udløbsdato. Udløbsdato er allerede passeret",
    "Sharing failed, because the user %s is the original sharer" : "Deling mislykkedes, fordi brugeren %s er den som delte oprindeligt",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deling af %s mislykkedes, fordi tilladelserne overskred de tillaldelser som %s var tildelt",
    "Sharing %s failed, because resharing is not allowed" : "Deling af %s mislykkedes, fordi videredeling ikke er tilladt",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling af %s mislykkedes, fordi back-enden ikke kunne finde kilden til %s",
    "Sharing %s failed, because the file could not be found in the file cache" : "Deling af %s mislykkedes, fordi filen ikke kunne findes i fil-cachen",
    "%s shared »%s« with you" : "%s delte »%s« med dig",
    "%s via %s" : "%s via %s",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App'en \"%s\" kan ikke installeres, da følgende krav ikke er opfyldt: %s ",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kræves"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/da.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive til mappen \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen",
    "See %s" : "Se %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen. Se %s",
    "Sample configuration detected" : "Eksempel for konfiguration registreret",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Der er registreret at eksempel for konfiguration er blevet kopieret. Dette kan ødelægge din installation og understøttes ikke. Læs venligst dokumentationen før der foretages ændringer i config.php",
    "%1$s and %2$s" : "%1$s og %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s og %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s og %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s og %5$s",
    "PHP %s or higher is required." : "Der kræves PHP %s eller nyere.",
    "PHP with a version lower than %s is required." : "Der kræves PHP %s eller ældre.",
    "Following databases are supported: %s" : "Følgende databaser understøttes: %s",
    "The command line tool %s could not be found" : "Kommandolinjeværktøjet %s blev ikke fundet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgængeligt.",
    "Following platforms are supported: %s" : "Følgende platforme understøttes: %s",
    "Server version %s or higher is required." : "Du skal have server version %s eller nyere.",
    "Server version %s or lower is required." : "Du skal have server version %s eller ældre.",
    "Authentication" : "Godkendelse",
    "Unknown filetype" : "Ukendt filtype",
    "Invalid image" : "Ugyldigt billede",
    "today" : "i dag",
    "tomorrow" : "i morgen",
    "yesterday" : "i går",
    "_in %n day_::_in %n days_" : ["om %n dag","om %n dage"],
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dage siden"],
    "next month" : "næste måned",
    "last month" : "sidste måned",
    "_in %n month_::_in %n months_" : ["om %n måned","om %n måneder"],
    "_%n month ago_::_%n months ago_" : ["%n måned siden","%n måneder siden"],
    "next year" : "næste år",
    "last year" : "sidste år",
    "_in %n year_::_in %n years_" : ["om %n år","om %n år"],
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_in %n hour_::_in %n hours_" : ["om %n time","om %n timer"],
    "_%n hour ago_::_%n hours ago_" : ["%n time siden","%n timer siden"],
    "_in %n minute_::_in %n minutes_" : ["om %n minut","om %n minutter"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minut siden","%n minutter siden"],
    "in a few seconds" : "om få sekunder",
    "seconds ago" : "sekunder siden",
    "File name is a reserved word" : "Filnavnet er et reserveret ord",
    "File name contains at least one invalid character" : "Filnavnet indeholder mindst ét ugyldigt tegn",
    "File name is too long" : "Filnavnet er for langt",
    "Dot files are not allowed" : "Filer med punktummer er ikke tilladt",
    "Empty filename is not allowed" : "Tomme filnavne er ikke tilladt",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres fordi appinfo filen ikke kan læses.",
    "__language_name__" : "Dansk",
    "Help" : "Hjælp",
    "Apps" : "Apps",
    "Settings" : "Indstillinger",
    "Log out" : "Log ud",
    "Users" : "Brugere",
    "Unknown user" : "Ukendt bruger",
    "Overview" : "Overblik",
    "Basic settings" : "Grundlæggende Indstillinger",
    "Sharing" : "Deling",
    "Security" : "Sikkerhed",
    "Additional settings" : "Yderligere indstillinger",
    "Personal info" : "Personlige oplysninger",
    "Mobile & desktop" : "Mobil & desktop",
    "%s enter the database username and name." : "%s indtast brugernavn og navn til databasen.",
    "%s enter the database username." : "%s indtast database brugernavnet.",
    "%s enter the database name." : "%s indtast database navnet.",
    "%s you may not use dots in the database name" : "%s du må ikke bruge punktummer i databasenavnet.",
    "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
    "Oracle username and/or password not valid" : "Oracle brugernavn og/eller kodeord er ikke gyldigt.",
    "PostgreSQL username and/or password not valid" : "PostgreSQL brugernavn og/eller kodeord er ikke gyldigt.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X understøttes ikke og %s vil ikke virke optimalt på denne platform. Anvend på eget ansvar!",
    "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
    "Set an admin username." : "Angiv et admin brugernavn.",
    "Set an admin password." : "Angiv et admin kodeord.",
    "Can't create or write into the data directory %s" : "Kan ikke oprette eller skrive ind i datamappen %s",
    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delingsbackend'en %s skal implementere grænsefladen OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delingsbackend'en %s blev ikke fundet",
    "Sharing backend for %s not found" : "Delingsbackend'en for %s blev ikke fundet",
    "Open »%s«" : "Åbn »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "Du har ikke tilladelse til at dele %s",
    "Expiration date is in the past" : "Udløbsdatoen ligger tilbage i tid",
    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
    "Could not find category \"%s\"" : "Kunne ikke finde kategorien \"%s\"",
    "Sunday" : "Søndag",
    "Monday" : "andag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : ".",
    "Thu." : "Tor.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Marts",
    "April" : "April",
    "May" : "Maj",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "eb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Maj",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kun følgende tegn kan indgå i et brugernavn: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
    "Username contains whitespace at the beginning or at the end" : "Brugernavnet har et mellemrum i starten eller slutningen",
    "A valid password must be provided" : "En gyldig adgangskode skal angives",
    "The username is already being used" : "Brugernavnet er allerede i brug",
    "User disabled" : "Bruger deaktiveret",
    "Login canceled by app" : "Login annulleret af app",
    "a safe home for all your data" : "et sikkert hjem til alle dine data",
    "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
    "Can't read file" : "Kan ikke læse filen",
    "Application is not enabled" : "Programmet er ikke aktiveret",
    "Authentication error" : "Adgangsfejl",
    "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen database driver (sqlite, mysql eller postgresql) er installeret.",
    "Cannot write into \"config\" directory" : "Kan ikke skrive til mappen \"config\"",
    "Cannot write into \"apps\" directory" : "Kan ikke skrive til mappen \"apps\"",
    "Setting locale to %s failed" : "Angivelse af %s for lokalitet mislykkedes",
    "Please install one of these locales on your system and restart your webserver." : "Installér venligst én af disse lokaliteter på dit system, og genstart din webserver.",
    "Please ask your server administrator to install the module." : "Du bedes anmode din serveradministrator om at installere modulet.",
    "PHP module %s not installed." : "PHP-modulet %s er ikke installeret.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-indstillingen \"%s\" er ikke angivet til \"%s\".",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload er angivet til \"%s\", i stedet for den forventede værdi \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "For at rette dette problem, angiv\n<code>mbstring.func_overload</code> til <code>0</code> i din php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 skal mindst være version 2.7.0. Du har version %s installeret.",
    "To fix this issue update your libxml2 version and restart your web server." : "Opdater din libxml2 version og genstart webserveren for at løse problemet.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP er tilsyneladende sat op til at fjerne indlejrede doc-blokke. Dette vil gøre adskillige kerneprogrammer utilgængelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette er sansynligvis forårsaget af et accelerator eller cache som Zend OPcache eller eAccelerator",
    "PHP modules have been installed, but they are still listed as missing?" : "Der er installeret PHP-moduler, men de fremstår stadig som fraværende?",
    "Please ask your server administrator to restart the web server." : "Du bedes anmode din serveradministrator om at genstarte webserveren.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kræves",
    "Please upgrade your database version" : "Opgradér venligst din databaseversion",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Tilpas venligst rettigheder til 0770, så mappen ikke fremvises for andre brugere.",
    "Check the value of \"datadirectory\" in your configuration" : "Tjek værdien for \"databibliotek\" i din konfiguration",
    "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\".",
    "Storage is temporarily not available" : "Lagerplads er midlertidigt ikke tilgængeligt",
    "Create" : "Opret",
    "Change" : "Ændr",
    "Delete" : "Slet",
    "Share" : "Del",
    "Unlimited" : "Ubegrænset",
    "Verifying" : "Bekræfter",
    "Verifying …" : "Bekræfter…",
    "Verify" : "Bekræft",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling af %s mislykkedes, fordi backenden ikke tillader delinger fra typen %i",
    "Sharing %s failed, because the file does not exist" : "Deling af %s mislykkedes, fordi filen ikke eksisterer",
    "Sharing %s failed, because you can not share with yourself" : "Deling af %s mislykkedes, fordi du ikke kan dele med dig selv",
    "You need to provide a password to create a public link, only protected links are allowed" : "Du skal angive et kodeord for at oprette et offentligt link - kun beskyttede links er tilladt",
    "Sharing %s failed, because sharing with links is not allowed" : "Der skete en fejl ved deling af %s, det er ikke tilladt at dele links",
    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan ikke angive udløbsdato. Delinger kan ikke udløbe senere end %s efter at de er blevet delt",
    "Cannot set expiration date. Expiration date is in the past" : "Kan ikke angive udløbsdato. Udløbsdato er allerede passeret",
    "Sharing failed, because the user %s is the original sharer" : "Deling mislykkedes, fordi brugeren %s er den som delte oprindeligt",
    "Sharing %s failed, because resharing is not allowed" : "Deling af %s mislykkedes, fordi videredeling ikke er tilladt",
    "Sharing %s failed, because the file could not be found in the file cache" : "Deling af %s mislykkedes, fordi filen ikke kunne findes i fil-cachen"
},
"nplurals=2; plural=(n != 1);");
